@@ -55,7 +55,7 @@ T Parser<T>::parse(const QString& xmlString)
     }
     if (xml.hasError()) {
         // TODO: error handling in metadata?
-        qWarning() << "XML Error: " << xml.errorString() << "\nIn XML:\n" << xmlString;
+        qWarning() << "parse():: XML Error: " << xml.errorString() << "\nIn XML:\n" << xmlString;
     }
 
     return item;
@@ -65,14 +65,63 @@ T Parser<T>::parse(const QString& xmlString)
 template <class T>
 typename T::List Parser<T>::parseList(const QString& xmlString)
 {
+/*
+        QString testxml = QString("<?xml version=\"1.0\"?>\
+<ocs>\
+ <meta>\
+  <status>ok</status>\
+  <statuscode>100</statuscode>\
+  <message></message>\
+ </meta>\
+ <data>\
+  <buildservice>\
+   <id>obs</id>\
+   <name>openSUSE Build Service</name>\
+   <registrationurl>foobar.com</registrationurl>\
+   <supportedtargets>\
+    <target>openSUSE 11.2 32bit Intel</target>\
+    <target>openSUSE 11.3 64bit Intel</target>\
+    <target>openSUSE 11.3 32bit Intel</target>\
+    <target>openSUSE 11.3 64bit Intel</target>\
+   </supportedtargets>\
+  </buildservice>\
+  <buildservice>\
+   <id>mbs</id>\
+   <name>MeeGo Build Service</name>\
+   <registrationurl>foobar42.com</registrationurl>\
+   <supportedtargets>\
+    <target>MeeGo 1.0 Intel</target>\
+    <target>MeeGo 1.0 ARM</target>\
+    <target>MeeGo 1.1 Intel</target>\
+    <target>MeeGo 1.1 ARM</target>\
+   </supportedtargets>\
+  </buildservice>\
+  <buildservice>\
+   <id>sbs</id>\
+   <name>Sebas' Build Service</name>\
+   <registrationurl>foobar42.com</registrationurl>\
+   <supportedtargets>\
+    <target>sebasix 1.3 33bit</target>\
+    <target>sebasis 4.4 14bit</target>\
+    <target>sebasix 1.3 65bit</target>\
+    <target>sebasis 4.4 37bit</target>\
+   </supportedtargets>\
+  </buildservice>\
+ </data>\
+</ocs>\
+ ");
+
+    qDebug() << "parsing list:" << xmlString;
+    */
     QStringList elements = xmlElement();
     typename T::List items;
 
+    //QXmlStreamReader xml( xmlString );
     QXmlStreamReader xml( xmlString );
 
     while (!xml.atEnd()) {
         xml.readNext();
-
+        //qDebug() << "parseList():: Looking for:" << xml.name().toString();
         if (xml.isStartElement()) {
             if (xml.name() == "data") {
                 while (!xml.atEnd()) {
@@ -83,6 +132,7 @@ typename T::List Parser<T>::parseList(const QString& xmlString)
                     }
 
                     if (xml.isStartElement() && elements.contains(xml.name().toString())) {
+                        //qDebug() << "xxxxxxxxx New Item!" << xml.name().toString();
                         items.append(parseXml(xml));
                     }
                 }
@@ -93,7 +143,7 @@ typename T::List Parser<T>::parseList(const QString& xmlString)
     }
     if (xml.hasError()) {
         // TODO: error handling in metadata?
-        qWarning() << "XML Error: " << xml.errorString() << "\nIn XML:\n" << xmlString;
+        qWarning() << "parseList():: XML Error: " << xml.errorString() << "\nIn XML:\n" << xmlString;
     }
 
 
