@@ -2,6 +2,7 @@
     This file is part of KDE.
 
     Copyright (c) 2009 Eckhart Wörner <ewoerner@kde.org>
+    Copyright (c) 2011 Laszlo Papp <djszapi@archlinux.us>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -24,7 +25,7 @@
 #ifndef ATTICA_QTPLATFORMDEPENDENT_H
 #define ATTICA_QTPLATFORMDEPENDENT_H
 
-#include "platformdependent.h"
+#include "platformdependent_v2.h"
 
 #include <QtCore/QHash>
 #include <QtNetwork/QNetworkAccessManager>
@@ -32,7 +33,7 @@
 
 namespace Attica {
 
-class QtPlatformDependent : public Attica::PlatformDependent
+class QtPlatformDependent : public Attica::PlatformDependentV2
 {
 public:
     virtual QList<QUrl> getDefaultProviderFiles() const;
@@ -40,7 +41,7 @@ public:
     virtual void removeDefaultProviderFile(const QUrl& url);
     virtual void enableProvider(const QUrl& baseUrl, bool enabled) const;
     virtual bool isEnabled(const QUrl& baseUrl) const;
-    
+
     virtual QNetworkReply* post(const QNetworkRequest& request, const QByteArray& data);
     virtual QNetworkReply* post(const QNetworkRequest& request, QIODevice* data);
     virtual QNetworkReply* get(const QNetworkRequest& request);
@@ -49,6 +50,9 @@ public:
     virtual bool loadCredentials(const QUrl& baseUrl, QString& user, QString& password);
     virtual bool askForCredentials(const QUrl& baseUrl, QString& user, QString& password);
     virtual QNetworkAccessManager* nam();
+    virtual QNetworkReply* deleteResource(const QNetworkRequest& request);
+    virtual QNetworkReply* put(const QNetworkRequest& request, const QByteArray& data);
+    virtual QNetworkReply* put(const QNetworkRequest& request, QIODevice* data);
 
 private:
     QNetworkAccessManager m_qnam;
